python-shaarli-client
=====================

.. image:: https://travis-ci.com/shaarli/python-shaarli-client.svg?branch=master
   :target: https://travis-ci.com/shaarli/python-shaarli-client
   :alt: Travis build status

.. image:: https://readthedocs.org/projects/python-shaarli-client/badge/?version=latest
   :target: http://python-shaarli-client.readthedocs.org/en/latest/?badge=latest
   :alt: Documentation Status

A Python 3 Command-Line Interface to interact with a Shaarli instance.
